@@ -1,5 +1,5 @@
 from django import forms
-from django.contrib.auth import get_user_model
+from django.contrib.auth import authenticate, login, get_user_model
 from django.utils.translation import ugettext_lazy as _
 
 
@@ -9,11 +9,42 @@ class SignupForm(forms.Form):
     password = forms.CharField(label=_('password'), widget=forms.PasswordInput)
     tos = forms.BooleanField(label=_('I accept the terms of service'))
 
+    def clean_email(self, *args, **kwargs):
+        data = self.cleaned_data['email']
+        user_model = get_user_model()
+        try:
+            user_model.objects.get(email=data)
+        except user_model.DoesNotExist:
+            return data
+        else:
+            raise forms.ValidationError(_("Email is already being used by another user"))
+
 
 class LoginForm(forms.Form):
     email = forms.EmailField(label=_('email'))
     password = forms.CharField(label=_('password'), widget=forms.PasswordInput)
 
+    def __init__(self, *args, **kwargs):
+        request = kwargs.pop('request', None)
+        self.request = request
+        return super(LoginForm, self).__init__(*args, **kwargs)
+
+    def clean(self, *args, **kwargs):
+        cleaned_data = super(LoginForm, self).clean()
+
+        # Check that email and password match and user is active
+        email = cleaned_data['email']
+        password = cleaned_data['password']
+        user = authenticate(email=email, password=password)
+        if user is None:
+            raise forms.ValidationError(_("Please insert both valid email and password"))
+        elif not user.is_active:
+            raise forms.ValidationError(_("Your account is inactive"))
+
+        # Login user
+        login(self.request, user)
+        return cleaned_data
+
 
 class UpdateEmailForm(forms.Form):
     email = forms.EmailField(required=True)
